#!/bin/sh
#set -x
export PATH=$PATH:/bin:./
AWK="/bin/awk"
CAT="/bin/cat"
SED="/bin/sed"
SLEEP="/bin/sleep"
LS="/bin/ls"
GREP="/bin/grep"
RM="/bin/rm"
MV="/bin/mv"
DATE="/bin/date"

S3SPFNAME=`uname`
case "${S3SPFNAME}" in
	"AIX" )
		S3SPVNAME="hdisk0"
		rm -f scsi3prsim
		ln -s scsi3prsim_a scsi3prsim
	;;
	"Linux" | * )
		S3SPVNAME="sda"
		rm -f scsi3prsim
		ln -s scsi3prsim_l scsi3prsim
	;;
esac

. ./s3sfunc.sh
# デバイス名が未指定 or KEYがOWNだけ指定
if [ "${1}" == "" ] || [ "${2}" != "" -a "${3}" == "" ]
then
	s3secho "usage:${0} <DEVICE_NAME> [<OWN_KEY> <OTHER_KEY>]"
	s3secho "DEVICE_NAME:"
	s3secho "    DEVICE_NAME to send SCSI commands to. Example '${0} /dev/${S3SPVNAME}'."
	s3secho "OWN_KEY:"
	s3secho "    OWN_KEY is assumed to be hex (up to 8 bytes long). Default value is '384'."
	s3secho "OTHER_KEY:"
	s3secho "    OTHER_KEY is assumed to be hex (up to 8 bytes long). Default value is '385'."
	exit 1
fi

# KEYの設定
OWN_KEY="384"
OTHER_KEY="385"
if [ "${2}" != "" ]
then
	OWN_KEY=${2}
	OTHER_KEY=${3}
fi
S3SLOGNM="log/scsi3PR_s3s_${OWN_KEY}.scsilog"

# 実行部
exec_shell(){
	if [ "${MODE}" = "Auto" ] && [ "${ORDER}" == 1 ]	# Autoの場合、1回目だけ表示する。
	then
		s3secho "Start 5   10  End"
		s3secho -n "  |   |    |   |
  "
	else
		:
	fi

	if [ `expr "${SH}" : [0-9]` -eq 1 ]
	then
		# Autoなら、スリープして、Manualなら人の入力待ち処理
		if [ "${MODE}" = "Auto" ]
		then
			s3secho "===== ${NO} start =====" >> ${S3SLOGNM}
			s3secho -n "."
			"${SLEEP}" "${SH}"
			s3secho "===== ${NO} end =====" >> ${S3SLOGNM}
		else
			s3secho "===== ${NO} start =====" >> ${S3SLOGNM}
			s3secho "===== ${ORDER}/14 start ====="
			s3secho "Own node sequence ${ORDER}/14 and other node sequence ${ORDER}/14 are both end,"
			s3secho "Please hit enter for go to next sequence."
			s3secho "===== ${NO} end =====" >> ${S3SLOGNM}
			s3secho -n "sequence ${ORDER}/14 end"
			read RDIN
		fi
	else
		# Autoであれば何もしない、Manualなら人の入力待ち処理
		if [ "${MODE}" = "Auto" ]
		then
			s3secho "===== ${NO} start =====" >> ${S3SLOGNM}
			s3secho -n "."
			"${SH}".sh "${1}" "${OWN_KEY}" "${OTHER_KEY}" "${2}"
			s3secho "===== ${NO} end =====" >> ${S3SLOGNM}
		else
			s3secho "===== ${NO} start =====" >> ${S3SLOGNM}
			s3secho "===== ${ORDER}/14 start ====="
			s3secho "Own node sequence ${ORDER}/14 and other node sequence ${ORDER}/14 are both end."
			s3secho "Please hit enter for go to next sequence."
			"${SH}".sh "${1}" "${OWN_KEY}" "${OTHER_KEY}" "${2}"
			s3secho "===== ${NO} end =====" >> ${S3SLOGNM}
			s3secho -n "sequence ${ORDER}/14 end"
			read RDIN
		fi
	fi
}

# メイン
SCSILOG_LIST=`${LS} -ct ./log/scsi3PR_s3s_* 2>/dev/null`
SCSILOG_CNT=`s3secho "${SCSILOG_LIST}" | ${GREP} -c "scsi3PR_s3s_*"`
if [ ${SCSILOG_CNT} -ge 5 ]
then
	RMLOG_LIST=`s3secho ${SCSILOG_LIST} | while read SVLOG1 SVLOG2 SVLOG3 SVLOG4 RMLOG_LIST;do s3secho $RMLOG_LIST;done`
	${RM} -f ${RMLOG_LIST}
fi

for LINE in `"${CAT}" ./Scenario`
do
	# '#'から始まる行は無視
	HEAD=`s3secho "${LINE}" | "${SED}" "s/#.*/#/g"`
	if [ "${HEAD}" = "#" ]
	then
		continue
	fi
	HEADD=`s3secho "${LINE}" | "${SED}" "s/%.*/%/g"`				# 実行モード読み取り用
	if [ "${HEADD}" = "%" ]
	then
		MODE=`s3secho "${LINE}" | "${AWK}" -F / '{print $2}'`
		continue
	fi

	ORDER=`s3secho "${LINE}" | "${AWK}" -F / '{print $1}'`		# 項番取得用

	if [ "${MODE}" != "Auto" ] && [ "${ORDER}" = 1 ]			# 手動実行のとき1回だけ表示する。
	then
		s3secho "Please go on to the next sequence, following the display."
	else
		:
	fi

	SH=`s3secho "${LINE}" | "${AWK}" -F / '{print $2}'`
	NO=`s3secho "${LINE}" | "${AWK}" -F / '{print $4}'`
	exec_shell ${1} ${4}

done

s3secho ""

./chklog.sh 1 ${OWN_KEY} ${OTHER_KEY}

${MV} ./log/scsi3PR_s3s_${OWN_KEY}.scsilog ./log/scsi3PR_s3s_${OWN_KEY}.scsilog_`${DATE} "+%Y%m%d-%H%M%S"`

s3secho "
Completed."

exit 0
